pub struct JavaScriptBridgeSignals;Expand description
Signal constants for JavaScriptBridge
Implementations
Sourceimpl JavaScriptBridgeSignals
impl JavaScriptBridgeSignals
Sourcepub const PWA_UPDATE_AVAILABLE: &'static str = "pwa_update_available"
pub const PWA_UPDATE_AVAILABLE: &'static str = "pwa_update_available"
Emitted when an update for this progressive web app has been detected but is waiting to be activated because a previous version is active. See pwa_update() to force the update to take place immediately.