SystemDeltaTimer

Struct SystemDeltaTimer 

pub struct SystemDeltaTimer<'w, 's> { /* private fields */ }
๐Ÿ‘ŽDeprecated:

Use PhysicsDelta instead

SystemParam to keep track of an independent delta time

Not every system runs on a Bevy update and Bevy can be updated multiple during a โ€œframeโ€.

Implementations

Source

impl<'w, 's> SystemDeltaTimer<'w, 's>

pub fn delta(&mut self) -> Duration

Returns the time passed since the last invocation

pub fn delta_seconds(&mut self) -> f32

pub fn delta_seconds_f64(&mut self) -> f64