pub struct DeferredConnection<T: Event + Clone + Send + 'static> {
pub signal_name: String,
pub mapper: Arc<dyn Fn(&[Variant], GodotNodeHandle, Option<Entity>) -> Option<T> + Send + Sync + 'static>,
}Expand description
A single deferred signal connection for event type T
Fields
signal_name: StringThe signal name to connect to
mapper: Arc<dyn Fn(&[Variant], GodotNodeHandle, Option<Entity>) -> Option<T> + Send + Sync + 'static>Mapper function to convert signal arguments to the event