pub struct GodotTransformSyncPlugin {
pub sync_mode: TransformSyncMode,
pub auto_sync: bool,
}Fields
sync_mode: TransformSyncModeThe mode for syncing transforms between Godot and Bevy.
Note: This setting is only relevant when auto_sync is true.
When auto_sync is false, this value is ignored since no automatic sync systems run.
auto_sync: boolWhen true (default), enables automatic transform syncing systems. When false, still registers Transform and TransformSyncMetadata components but allows defining custom sync systems using the add_transform_sync_systems_*! macros.