pub struct SystemDeltaTimer<'w, 's> { /* private fields */ }๐Deprecated:
Use PhysicsDelta instead
SystemParam to keep track of an independent delta time
Not every system runs on a Bevy update and Bevy can be updated multiple during a โframeโ.
Implementations
Sourceimpl<'w, 's> SystemDeltaTimer<'w, 's>
impl<'w, 's> SystemDeltaTimer<'w, 's>
pub fn delta_seconds(&mut self) -> f32
pub fn delta_seconds_f64(&mut self) -> f64